# eric7.Plugins.VcsPlugins.vcsGit.GitRevisionSelectionDialog

Module implementing a dialog to select a revision.

### Global Attributes

None

### Classes

GitRevisionSelectionDialog | Class implementing a dialog to select a revision.

### Functions

None

## GitRevisionSelectionDialog

Class implementing a dialog to select a revision.

### Derived from

QDialog, Ui_GitRevisionSelectionDialog

### Class Attributes

None

### Class Methods

None

### Methods

GitRevisionSelectionDialog | Constructor
__updateOK | Private slot to update the OK button.
getRevision | Public method to retrieve the selected revision.
on_branchButton_toggled | Private slot to handle changes of the Branch select button.
on_branchCombo_editTextChanged | Private slot to handle changes of the Branch combo.
on_remoteBranchButton_toggled | Private slot to handle changes of the Remote Branch select button.
on_remoteBranchCombo_editTextChanged | Private slot to handle changes of the Remote Branch combo.
on_revButton_toggled | Private slot to handle changes of the rev select button.
on_revEdit_textChanged | Private slot to handle changes of the rev edit.
on_tagButton_toggled | Private slot to handle changes of the Tag select button.
on_tagCombo_editTextChanged | Private slot to handle changes of the Tag combo.

### Static Methods

None

#### GitRevisionSelectionDialog (Constructor)

GitRevisionSelectionDialog(tagsList, branchesList, trackingBranchesList=None, noneLabel="", showBranches=True, showHead=True, parent=None, )

Constructor

tagsList (list of str)
  list of tags
branchesList (list of str)
  list of branches
trackingBranchesList (list of str)
  list of remote branches
noneLabel (str)
  label text for "no revision selected"
showBranches (bool)
  flag indicating to show the branch selection
showHead (bool)
  flag indicating to show the head selection
parent (QWidget)
  parent widget

#### GitRevisionSelectionDialog.__updateOK

__updateOK()

Private slot to update the OK button.

#### GitRevisionSelectionDialog.getRevision

getRevision()

Public method to retrieve the selected revision.

Return:
  selected revision

Return Type:
  str

#### GitRevisionSelectionDialog.on_branchButton_toggled

on_branchButton_toggled(_checked)

Private slot to handle changes of the Branch select button.

_checked (bool)
  state of the button (unused)

#### GitRevisionSelectionDialog.on_branchCombo_editTextChanged

on_branchCombo_editTextChanged(_txt)

Private slot to handle changes of the Branch combo.

_txt (str)
  text of the combo (unused)

#### GitRevisionSelectionDialog.on_remoteBranchButton_toggled

on_remoteBranchButton_toggled(_checked)

Private slot to handle changes of the Remote Branch select button.

_checked (bool)
  state of the button (unused)

#### GitRevisionSelectionDialog.on_remoteBranchCombo_editTextChanged

on_remoteBranchCombo_editTextChanged(_txt)

Private slot to handle changes of the Remote Branch combo.

_txt (str)
  text of the combo (unused)

#### GitRevisionSelectionDialog.on_revButton_toggled

on_revButton_toggled(_checked)

Private slot to handle changes of the rev select button.

_checked (bool)
  state of the button (unused)

#### GitRevisionSelectionDialog.on_revEdit_textChanged

on_revEdit_textChanged(_txt)

Private slot to handle changes of the rev edit.

_txt (str)
  text of the edit (unused)

#### GitRevisionSelectionDialog.on_tagButton_toggled

on_tagButton_toggled(_checked)

Private slot to handle changes of the Tag select button.

_checked (bool)
  state of the button (unused)

#### GitRevisionSelectionDialog.on_tagCombo_editTextChanged

on_tagCombo_editTextChanged(_txt)

Private slot to handle changes of the Tag combo.

_txt (str)
  text of the combo (unused)

Up